==> r-cran-plotrix_3.4-7.orig.tar.gz: plotrix/man/floating.pie.Rd <==
\name{floating.pie}
\alias{floating.pie}
\title{Display a floating pie chart}
\description{
 Displays a pie chart at an arbitrary position on an existing plot
}
\usage{
 floating.pie(xpos,ypos,x,edges=200,radius=1,col=NULL,startpos=0,
  shadow=FALSE,shadow.col=c("#ffffff","#cccccc"),...)
}
\arguments{
 \item{xpos,ypos}{x and y position of the center of the pie chart}
 \item{x}{a numeric vector for which each value will be a sector}
 \item{edges}{the number of lines forming a circle}
 \item{radius}{the radius of the pie in user units}
 \item{col}{the colors of the sectors - defaults to \samp{rainbow}}
 \item{startpos}{The starting position for drawing sectors in radians.}
 \item{shadow}{Logical - whether to draw a shadow}
 \item{shadow.col}{Colors to use for a shadow.}
 \item{...}{graphical parameters passed to \samp{polygon}}
}
\details{
 \samp{floating.pie} displays a pie chart with an optional shadow on an
 existing plot (see \samp{polygon.shadow}).
}
\value{
 The bisecting angle of the sectors in radians. Useful for placing
 text labels for each sector.
}
\note{
 As with most pie charts, simplicity is essential. Trying to display a
 complicated breakdown of data rarely succeeds.
}
\author{Jim Lemon}
\seealso{\link{pie.labels}, \link{boxed.labels}, \link{polygon.shadow}}
\examples{
 plot(1:5,type="n",main="Floating Pie test",xlab="",ylab="",axes=FALSE)
 box()
 polygon(c(0,0,5.5,5.5),c(0,3,3,0),border="#44aaff",col="#44aaff")
 floating.pie(1.7,3,c(2,4,4,2,8),radius=0.5,
  col=c("#ff0000","#80ff00","#00ffff","#44bbff","#8000ff"))
 floating.pie(3.1,3,c(1,4,5,2,8),radius=0.5,
  col=c("#ff0000","#80ff00","#00ffff","#44bbff","#8000ff"))
 floating.pie(4,1.5,c(3,4,6,7),radius=0.5,
  col=c("#ff0066","#00cc88","#44bbff","#8000ff"))
 draw.circle(3.9,2.1,radius=0.04,col="white")
 draw.circle(3.9,2.1,radius=0.04,col="white")
 draw.circle(3.9,2.1,radius=0.04,col="white")
 draw.circle(4,2.3,radius=0.04,col="white")
 draw.circle(4.07,2.55,radius=0.04,col="white")
 draw.circle(4.03,2.85,radius=0.04,col="white")
 text(c(1.7,3.1,4),c(3.7,3.7,3.7),c("Pass","Pass","Fail"))
}
\keyword{misc}

==> r-cran-plotrix_3.6.orig.tar.gz: plotrix/man/floating.pie.Rd <==
\name{floating.pie}
\alias{floating.pie}
\title{Display a floating pie chart}
\description{
 Displays a pie chart at an arbitrary position on an existing plot
}
\usage{
 floating.pie(xpos,ypos,x,edges=200,radius=1,col=NULL,startpos=0,
  shadow=FALSE,shadow.col=c("#ffffff","#cccccc"),...)
}
\arguments{
 \item{xpos,ypos}{x and y position of the center of the pie chart}
 \item{x}{a numeric vector for which each value will be a sector}
 \item{edges}{the number of lines forming a circle}
 \item{radius}{the radius of the pie in user units}
 \item{col}{the colors of the sectors - defaults to \samp{rainbow}}
 \item{startpos}{The starting position for drawing sectors in radians.}
 \item{shadow}{Logical - whether to draw a shadow}
 \item{shadow.col}{Colors to use for a shadow.}
 \item{...}{graphical parameters passed to \samp{polygon}}
}
\details{
 \samp{floating.pie} displays a pie chart with an optional shadow on an
 existing plot (see \samp{polygon.shadow}). \samp{floating.pie} now accepts
 NAs or zeros in \samp{x}, but simply ignores them.

 \samp{floating.pie} can be useful when multiple pie charts are placed on a
 plot overlaying something else, like a map.
}
\value{
 The bisecting angle of the sectors in radians. Useful for placing
 text labels for each sector. If any values in \samp{x} were zero or NA,
 no angle is returned for that value. This means that the user must adjust
 the labels accordingly if \samp{pie.labels} is called.
}
\note{
 As with most pie charts, simplicity is essential. Trying to display a
 complicated breakdown of data rarely succeeds. The example of bullying
 is about as complex as one can get with a pie chart and still convey the
 relevant information.
}
\author{Jim Lemon}
\references{
 Li, Q. (2006) Cyberbullying in schools: A research of gender differences.
 School Psychology International, 27(2): 157-170.
}
\seealso{\link{pie.labels}, \link{boxed.labels}, \link{polygon.shadow}}
\examples{
 plot(1:5,type="n",main="Floating Pie test",xlab="",ylab="",axes=FALSE)
 box()
 polygon(c(0,0,5.5,5.5),c(0,3,3,0),border="#44aaff",col="#44aaff")
 floating.pie(1.7,3,c(2,4,4,2,8),radius=0.5,
  col=c("#ff0000","#80ff00","#00ffff","#44bbff","#8000ff"))
 floating.pie(3.1,3,c(1,4,5,2,8),radius=0.5,
  col=c("#ff0000","#80ff00","#00ffff","#44bbff","#8000ff"))
 floating.pie(4,1.5,c(3,4,6,7),radius=0.5,
  col=c("#ff0066","#00cc88","#44bbff","#8000ff"))
 draw.circle(3.9,2.1,radius=0.04,col="white")
 draw.circle(3.9,2.1,radius=0.04,col="white")
 draw.circle(3.9,2.1,radius=0.04,col="white")
 draw.circle(4,2.3,radius=0.04,col="white")
 draw.circle(4.07,2.55,radius=0.04,col="white")
 draw.circle(4.03,2.85,radius=0.04,col="white")
 text(c(1.7,3.1,4),c(3.7,3.7,3.7),c("Pass","Pass","Fail"))
 # type of bullying by sex as superimposed pies
 plot(0,xlim=c(-1,1),ylim=c(-1,1),type="n",axes=FALSE,
  main="Type of bullying by sex (Li, 2006)")
 bc<-floating.pie(0,0,c(90,129,45,67),radius=1,col=2:5)
 pie.labels(0,0,bc,c("Physical\nbully","Physical\nvictim",
  "Cyber\nbully","Cyber\nvictim"))
 bc<-floating.pie(0,0,c(53,37,70,59,29,16,33,34),
  radius=0.7,col=c("lightblue","pink"))
 pie.labels(0,0,bc,radius=0.5,labels=rep(c("M","F"),4))
}
\keyword{misc}
